ZardFormSnapshot class

Annotations

Constructors

ZardFormSnapshot({required bool isValid, required bool isDirty, required bool isTouched, required bool isSubmitting, required bool isValidating, required int submitCount, required bool disabled, required List<String> formErrors})
const

Properties

disabled bool
final
formErrors List<String>
final
hashCode int
The hash code for this object.
no setteroverride
isDirty bool
final
isSubmitting bool
final
isTouched bool
final
isValid bool
final
isValidating bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
submitCount int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Static Methods

from(ZardFormController f) ZardFormSnapshot